@@ -11,6 +11,7 @@ COPYRIGHT
 import functools
 import inspect
 import logging
+from pathlib import PurePath
 import time
 import timeit
 
@@ -23,7 +24,8 @@ class Log:
         self.call_count = 0
         self.func = func
         self.func_name = self.func.__name__
-        self.func_filename = inspect.getfile(self.func)
+        self.func_filepath = inspect.getfile(self.func)
+        self.func_filename = PurePath(self.func_filepath).name
         self.func_lineno = inspect.getsourcelines(self.func)[1]
 
     def __call__(self, *args, **kwargs):
