@@ -133,7 +133,7 @@ class NeatlogFormatter(logging.Formatter):
             else:
                 levelname_width = 8
             self.fmt += (
-                f"%(asctime)s{sep}{stem}{sep}%(_filename)s:%(_lineno)d{sep}%(_funcName)s{sep}"
+                f"%(asctime)s{sep}{stem}{sep}%(_filename)s:%(_lineno)-4d{sep}%(_funcName)s{sep}"
                 f"%(levelname)-{levelname_width}s{sep}%(message)s"
             )
 
